==> wowit-0.4.27.tar.gz: lib/common.dart <==
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:wowit/controllers/connect_controller.dart';
import 'package:wowit/message.dart';
import 'package:wowit/widgets/common_widget.dart';

import 'model.dart';

class CoutryPhoneNumber {
  String countryCode = '';
  String phoneHeaderCode = '';
  List<String> listStartPhoneHeader = [];

  CoutryPhoneNumber(
      this.countryCode, this.phoneHeaderCode, this.listStartPhoneHeader);
}

class Common {
  static String phoneNumberInput = '';
  static String fakeLoginPhone = '+84364857788';
  static String fakeLoginUidPhone = 'cZElX1GhkoWmRRqYP9Q5qXGUWJb2';
  static String getUidPhone() {
    if (Common.fakeLoginPhone == phoneNumberInput) return fakeLoginUidPhone;
    return FirebaseAuth.instance.currentUser?.uid ?? '';
  }

  static String getPhoneNumber() {
    if (Common.fakeLoginPhone == phoneNumberInput) return fakeLoginPhone;
    return FirebaseAuth.instance.currentUser?.phoneNumber ?? '';
  }

  static int idDb = 0;
  static int uid = -1;
  static String? deviceId;
  static String? deviceName;
  static String uidPhone = '';
  static int languageId = 1;
  static late Widget loadingScreen = const LoadingScreen();
  static late Widget registerScreen;
  static late Widget noInternetScreen = const NoInternetScreen();

  static bool supperAdmin = false;
  static bool showKeyMessage = false;
  static bool canGetMessage = true;
  static bool autoCreateMessage = true;
  static bool notGetMessage = false;
  static const bool useValidFirebase = false;

  static Color colorAppbar = const Color(0xff2a367e);

  // ignore: non_constant_identifier_names
  static String url_host = '';
  // ignore: constant_identifier_names
  static const String FOLDER_IMAGE_UPLOAD = 'images/Upload';
  // ignore: constant_identifier_names
  static const String DEFAULT_IMAGE_URL =
      'images/Upload/tblHinhAnh/3393/default.jpg';

  static late int fVersion;

  static bool get isOnline => MyConnectivity.instance.isOnline;

  static Map<String, String> mapMessageData = {};
  static Map<String, String> messageIdBackUp = {};
  static Map<String, List<KeyValue>> mapPicker = {};
  static Map<String, Map<int, RangeValue>> mapRange = {};
  static Map<String, Map<String, Object?>> mapImage = {};

  static void initWowIT({
    required Map<String, String> messsageLabel,
    required String host,
    required int idDatabase,
  }) {
    mapMessageData = messsageLabel;
    url_host = host;
    idDb = idDatabase;
    _tienDonVi.clear();
  }

  static List<CoutryPhoneNumber> listCoutryPhoneNumber = [
    CoutryPhoneNumber('vn', '+84', [
      '059',
      '081',
      '082',
      '083',
      '059',
      '079',
      '096',
      '097',
      '098',
      '032',
      '033',
      '034',
      '035',
      '036',
      '037',
      '038',
      '039',
      '090',
      '093',
      '070',
      '071',
      '072',
      '076',
      '077',
      '078',
      '091',
      '094',
      '083',
      '084',
      '085',
      '087',
      '089',
      '099',
      '092',
      '056',
      '058',
      '095',
      '088',
    ])
  ];
  static List<String> _tienDonVi = [];
  static const List<double> tienSo = [
    1000000000000000.0,
    1000000000000.0,
    1000000000.0,
    1000000.0,
    1000.0,
    1
  ];

  static List<String> getTienDonVi(bool rutGon) {
    if (_tienDonVi.isEmpty) {
      if (rutGon) {
        _tienDonVi = [
          Message.getMessage('DON_VI_TIEN_TRIEU_TY_RUT_GON'),
          Message.getMessage('DON_VI_TIEN_NGIN_TY_RUT_GON'),
          Message.getMessage('DON_VI_TIEN_TY_RUT_GON'),
          Message.getMessage('DON_VI_TIEN_TRIEU_RUT_GON'),
          Message.getMessage('DON_VI_TIEN_NGIN_RUT_GON'),
          Message.getMessage('DON_VI_TIEN_DONG_RUT_GON')
        ];
      } else {
        _tienDonVi = [
          Message.getMessage('DON_VI_TIEN_TRIEU_TY'),
          Message.getMessage('DON_VI_TIEN_NGIN_TY'),
          Message.getMessage('DON_VI_TIEN_TY'),
          Message.getMessage('DON_VI_TIEN_TRIEU'),
          Message.getMessage('DON_VI_TIEN_NGIN'),
          Message.getMessage('DON_VI_TIEN_DONG')
        ];
      }
    }

    return _tienDonVi;
  }

  static void setupDefaultData() {
    if (Common.mapMessageData.isEmpty) {
      Common.mapMessageData = {
        'REGISTER_ACCOUNTNAME': 'Tên tài khoản',
        'REGISTER_BAN_CHUA_NHAP_SDT': 'Nhâp số điện thoại',
        'REGISTER_CO_LOI_PHAT_SINH_VUI_LONG_THU_LAI_SAU':
            'Có lỗi phát sinh, vui lòng kiểm tra mạng Internet của bạn và thử lại sau.',
        'REGISTER_DANG_CHO_XAC_THUC': 'Đang chờ xác thực',
        'REGISTER_EMAIL': 'E-mail',
        'REGISTER_ENTER_THEPASSWORD': 'Nhập lại mật khẩu',
        'REGISTER_GUI': 'Gửi',
        'REGISTER_HAVE_ANACOUNT': 'Đã có tài khoản?',
        'REGISTER_INVALID_OTP_CODE': 'OTP không hợp lệ',
        'REGISTER_INVALID_PHONE_NUMBER': 'Số điện thoại không đúng định dạng',
        'REGISTER_LANGUAGE': 'Ngôn ngữ',
        'REGISTER_LOGIN_NOW': 'Đăng nhập ngay',
        'REGISTER_NHAP_MA_OTP_DE_XAC_THUC': 'Nhập mã OTP để xác thực',
        'REGISTER_NHAP_OPT_DE_XAC_THUC': 'Nhập mã OTP để xác thực',
        'REGISTER_NHAP_SDT_DE_DANG_NHAP_HOAC_DANG_KY':
            'Dùng số điện thoại để đăng ký hoặc đăng nhập',
        'REGISTER_NHAP_SO_DIEN_THOAI': 'Nhập số điện thoại',
        'REGISTER_PASSWORD': 'Mật khẩu',
        'REGISTER_PHONENUMBER': 'Số điện thoại',
        'REGISTER_REGISTER': 'Đăng ký',
        'REGISTER_SO_DIEN_THOAI_KHONG_DUNG':
            'Số điện thoại không đúng định dạng',
        'REGISTER_THE_BLOCK_REQUEST':
            'Chúng tôi đã chặn tất cả các yêu cầu từ thiết bị này do hoạt động bất thường. Vui lòng thử lại sau ít phút',
        'REGISTER_THE_SMS_HAS_EXPIRED': 'Mã SMS đã hết hạn. Vui lòng thử lại',
        'REGISTER_THE_SMS_OPT_IN_VALID':
            'OTP không chính xác, vui lòng thử lại',
        'REGISTER_THE_SMS_TIME_OUT':
            'Quá thời gian gửi OTP vui lại kiểm tra mạng và thử lại',
        'REGISTER_THONG_BAO': 'Thông báo',
        'REGISTER_TIEP_TUC': 'Tiếp tục',
        'REGISTER_INVALID_RELOGIN': 'Vui lòng đăng nhập lại',
        'REGISTER_INVALID_LOGIN_THIETBIKHAC':
            'Tài khoản của bạn đã được đăng nhập ở thiết bị',
        'REGISTER_BUTOTN_OK': 'OK',
        'LOGIN_ACCOUNT': 'Account',
        'LOGIN_NHAPMAOTP': 'Nhập mã OTP',
        'LOGIN_NHAPSDT': 'Số điện thoại',
        'LOGIN_THAYDOISDT': 'Thay đổi số điện thoại',
        'LOGIN_WELCOME': 'Chào mừng bạn đến với',
        'RESET_PASSWORD_CONFIRM': 'Xác nhận',
        'RESET_PASSWORD_NEWPASSWORD': 'Nhập mật khẩu mới',
        'RESET_PASSWORD_THEPASSWORD': 'Nhập lại mật khẩu',
        'THONGBAONOSUPPORT_KHONGHOTRO':
            'không được hỗ trợ. Vui lòng nâng cấp phiên bản mới và thử lại',
        'THONGBAONOSUPPORT_PHIENBAN': 'Bạn đang sử dụng phiên bản',
        'LOGIN_THONG_BAO_LOGGIN_FAILL':
            'Lỗi đăng nhập! Vui lòng liên hệ admin để biết thêm chi tiết.',
        'LOGIN_BUTTON_CLOSE': 'Đóng',
        'LOGIN_THONG_BAO_KHONG_CO_INTERNET':
            'Lỗi Internet! vui lòng kiểm tra lại',
        'INTERNET_ERROR': 'Không có internet',
        'INTERNET_OK': 'Ok'
      };
    }

    if (Common.mapImage.isEmpty) {
      Common.mapImage = {
        '48': {
          'hinhAnh_image_path': 'images/Upload/tblHinhAnh/48/bg_login.png',
        },
      };
    }
  }
}

==> wowit-0.4.46.tar.gz: lib/common.dart <==
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:wowit/controllers/wow_connectivity.dart';
import 'package:wowit/message.dart';
import 'package:wowit/widgets/common_widget.dart';

import 'model.dart';

class CoutryPhoneNumber {
  String countryCode = '';
  String phoneHeaderCode = '';
  List<String> listStartPhoneHeader = [];

  CoutryPhoneNumber(
      this.countryCode, this.phoneHeaderCode, this.listStartPhoneHeader);
}

class Common {
  Common._();

  static String phoneNumberInput = '';
  static String fakeLoginPhone = '+84364857788';
  static String fakeLoginUidPhone = 'cZElX1GhkoWmRRqYP9Q5qXGUWJb2';
  static String getUidPhone() {
    if (Common.fakeLoginPhone == phoneNumberInput) return fakeLoginUidPhone;
    return FirebaseAuth.instance.currentUser?.uid ?? '';
  }

  static String getPhoneNumber() {
    if (Common.fakeLoginPhone == phoneNumberInput) return fakeLoginPhone;
    return FirebaseAuth.instance.currentUser?.phoneNumber ?? '';
  }

  static int idDb = 0;
  static int uid = -1;
  static String? deviceId;
  static String? deviceName;
  static int languageId = 1;
  static late Widget loadingScreen = const LoadingScreen();
  static late Widget registerScreen;
  static late Widget noInternetScreen = const NoInternetScreen();

  static bool supperAdmin = false;
  static bool showKeyMessage = false;
  static bool canGetMessage = true;
  static bool autoCreateMessage = true;
  static bool notGetMessage = false;
  static const bool useValidFirebase = false;

  static Color colorAppbar = const Color(0xff2a367e);

  // ignore: non_constant_identifier_names
  static String url_host = '';
  // ignore: constant_identifier_names
  static const String FOLDER_IMAGE_UPLOAD = 'images/Upload';
  // ignore: constant_identifier_names
  static const String DEFAULT_IMAGE_URL =
      'images/Upload/tblHinhAnh/3393/default.jpg';

  static late int fVersion;
  static bool get isOnline => WowConnectivity().isOnline;

  static Map<String, String> mapMessageData = {};
  static Map<String, String> messageIdBackUp = {};
  static Map<String, List<KeyValue>> mapPicker = {};
  static Map<String, Map<int, RangeValue>> mapRange = {};
  static Map<String, Map<String, Object?>> mapImage = {};

  static void initWowIT({
    required Map<String, String> messsageLabel,
    required String host,
    required int idDatabase,
  }) {
    mapMessageData = messsageLabel;
    url_host = host;
    idDb = idDatabase;
    _tienDonVi.clear();
  }

  static List<CoutryPhoneNumber> listCoutryPhoneNumber = [
    CoutryPhoneNumber('vn', '+84', [
      '059',
      '081',
      '082',
      '083',
      '059',
      '079',
      '096',
      '097',
      '098',
      '032',
      '033',
      '034',
      '035',
      '036',
      '037',
      '038',
      '039',
      '090',
      '093',
      '070',
      '071',
      '072',
      '076',
      '077',
      '078',
      '091',
      '094',
      '083',
      '084',
      '085',
      '087',
      '089',
      '099',
      '092',
      '056',
      '058',
      '095',
      '088',
      '086',
    ])
  ];
  static List<String> _tienDonVi = [];
  static const List<double> tienSo = [
    1000000000000000.0,
    1000000000000.0,
    1000000000.0,
    1000000.0,
    1000.0,
    1
  ];

  static List<String> getTienDonVi(bool rutGon) {
    if (_tienDonVi.isEmpty) {
      if (rutGon) {
        _tienDonVi = [
          Message.getMessage('DON_VI_TIEN_TRIEU_TY_RUT_GON'),
          Message.getMessage('DON_VI_TIEN_NGIN_TY_RUT_GON'),
          Message.getMessage('DON_VI_TIEN_TY_RUT_GON'),
          Message.getMessage('DON_VI_TIEN_TRIEU_RUT_GON'),
          Message.getMessage('DON_VI_TIEN_NGIN_RUT_GON'),
          Message.getMessage('DON_VI_TIEN_DONG_RUT_GON')
        ];
      } else {
        _tienDonVi = [
          Message.getMessage('DON_VI_TIEN_TRIEU_TY'),
          Message.getMessage('DON_VI_TIEN_NGIN_TY'),
          Message.getMessage('DON_VI_TIEN_TY'),
          Message.getMessage('DON_VI_TIEN_TRIEU'),
          Message.getMessage('DON_VI_TIEN_NGIN'),
          Message.getMessage('DON_VI_TIEN_DONG')
        ];
      }
    }

    return _tienDonVi;
  }

  static void setupDefaultData() {
    if (Common.mapMessageData.isEmpty) {
      Common.mapMessageData = {
        'REGISTER_ACCOUNTNAME': 'Tên tài khoản',
        'REGISTER_BAN_CHUA_NHAP_SDT': 'Nhâp số điện thoại',
        'REGISTER_CO_LOI_PHAT_SINH_VUI_LONG_THU_LAI_SAU':
            'Có lỗi phát sinh, vui lòng kiểm tra mạng Internet của bạn và thử lại sau.',
        'REGISTER_DANG_CHO_XAC_THUC': 'Đang chờ xác thực',
        'REGISTER_EMAIL': 'E-mail',
        'REGISTER_ENTER_THEPASSWORD': 'Nhập lại mật khẩu',
        'REGISTER_GUI': 'Gửi',
        'REGISTER_HAVE_ANACOUNT': 'Đã có tài khoản?',
        'REGISTER_INVALID_OTP_CODE': 'OTP không hợp lệ',
        'REGISTER_INVALID_PHONE_NUMBER': 'Số điện thoại không đúng định dạng',
        'REGISTER_LANGUAGE': 'Ngôn ngữ',
        'REGISTER_LOGIN_NOW': 'Đăng nhập ngay',
        'REGISTER_NHAP_MA_OTP_DE_XAC_THUC': 'Nhập mã OTP để xác thực',
        'REGISTER_NHAP_OPT_DE_XAC_THUC': 'Nhập mã OTP để xác thực',
        'REGISTER_NHAP_SDT_DE_DANG_NHAP_HOAC_DANG_KY':
            'Dùng số điện thoại để đăng ký hoặc đăng nhập',
        'REGISTER_NHAP_SO_DIEN_THOAI': 'Nhập số điện thoại',
        'REGISTER_PASSWORD': 'Mật khẩu',
        'REGISTER_PHONENUMBER': 'Số điện thoại',
        'REGISTER_REGISTER': 'Đăng ký',
        'REGISTER_SO_DIEN_THOAI_KHONG_DUNG':
            'Số điện thoại không đúng định dạng',
        'REGISTER_THE_BLOCK_REQUEST':
            'Chúng tôi đã chặn tất cả các yêu cầu từ thiết bị này do hoạt động bất thường. Vui lòng thử lại sau ít phút',
        'REGISTER_THE_SMS_HAS_EXPIRED': 'Mã SMS đã hết hạn. Vui lòng thử lại',
        'REGISTER_THE_SMS_OPT_IN_VALID':
            'OTP không chính xác, vui lòng thử lại',
        'REGISTER_THE_SMS_TIME_OUT':
            'Quá thời gian gửi OTP vui lại kiểm tra mạng và thử lại',
        'REGISTER_THONG_BAO': 'Thông báo',
        'REGISTER_TIEP_TUC': 'Tiếp tục',
        'REGISTER_INVALID_RELOGIN': 'Vui lòng đăng nhập lại',
        'REGISTER_INVALID_LOGIN_THIETBIKHAC':
            'Tài khoản của bạn đã được đăng nhập ở thiết bị',
        'REGISTER_BUTOTN_OK': 'OK',
        'LOGIN_ACCOUNT': 'Account',
        'LOGIN_NHAPMAOTP': 'Nhập mã OTP',
        'LOGIN_NHAPSDT': 'Số điện thoại',
        'LOGIN_THAYDOISDT': 'Thay đổi số điện thoại',
        'LOGIN_WELCOME': 'Chào mừng bạn đến với',
        'RESET_PASSWORD_CONFIRM': 'Xác nhận',
        'RESET_PASSWORD_NEWPASSWORD': 'Nhập mật khẩu mới',
        'RESET_PASSWORD_THEPASSWORD': 'Nhập lại mật khẩu',
        'THONGBAONOSUPPORT_KHONGHOTRO':
            'không được hỗ trợ. Vui lòng nâng cấp phiên bản mới và thử lại',
        'THONGBAONOSUPPORT_PHIENBAN': 'Bạn đang sử dụng phiên bản',
        'LOGIN_THONG_BAO_LOGGIN_FAILL':
            'Lỗi đăng nhập! Vui lòng liên hệ admin để biết thêm chi tiết.',
        'LOGIN_BUTTON_CLOSE': 'Đóng',
        'LOGIN_THONG_BAO_KHONG_CO_INTERNET':
            'Lỗi Internet! vui lòng kiểm tra lại',
        'INTERNET_ERROR': 'Không có internet',
        'INTERNET_OK': 'Ok'
      };
    }

    if (Common.mapImage.isEmpty) {
      Common.mapImage = {
        '48': {
          'hinhAnh_image_path': 'images/Upload/tblHinhAnh/48/bg_login.png',
        },
      };
    }
  }
}
